@@ -175,7 +175,7 @@ sub alternatives {
 
 #<<<
             @partial = (
-                List::UtilsBy::XS::nsort_by { $Math::Bacovia::HIERARCHY{ref($_)} }
+                List::UtilsBy::nsort_by { $Math::Bacovia::HIERARCHY{ref($_)} }
                 grep { ref($_) ne 'Math::Bacovia::Number' or $_->{value} != 1 } @partial
             );
 #>>>
@@ -190,7 +190,7 @@ sub alternatives {
         }
         map { [$_->alternatives(%opt)] } @{$x->{values}};
 
-        [List::UtilsBy::XS::uniq_by { $_->stringify } @alt];
+        [List::UtilsBy::uniq_by { $_->stringify } @alt];
     };
 
     @{$x->{_alt}};
